* fork fp.py into benchmarking and non-benchmarking versions?
* consider and implement a modular fp backend:
  * https://pypi.org/project/pyfinite/
  * https://pypi.org/project/gmpy2/
  * others?
* integrate bsidh key validation (only supersingular validation is implemented)
* integrate sidh, and sike, and key encapsulation for bsidh
* integrate signature schemes based on isogenies
* integrate different curve models such as [Edwards](https://eprint.iacr.org/2019/843.pdf) and [Huff](https://eprint.iacr.org/2021/085.pdf)